#!/usr/bin/env nextflow

// Using DSL-2
nextflow.enable.dsl=2

// All of the default parameters are being set in `nextflow.config`

// Import sub-workflows
include { sra_pull } from './modules/sra_pull'

// Function which prints help message text
def helpMessage() {
	log.info"""
    Usage:
    nextflow run dbGaP_to_blob <ARGUMENTS>

    Required Arguments:

	ACCESSION:
	--acc                 Accession ID of file to download

	MANIFEST:
	--manifest            Text file of manifest of accession IDs

	Output Location:
	--output_folder       Folder for output files
	""".stripIndent()
}

// Main workflow
workflow {

	// Show help message or flag help message if missing required CL arg
	if ( params.help || (params.acc == false && params.manifest == false) || \
	    params.output_folder == false ){
		// Print help function above
		helpMessage()
		exit 1
	}
	// Single-file download from dbGaP
	if (params.manifest == false) {
		sra_pull(params.acc)
	// Multi-file download from dbGaP
	} else if (params.acc == false) {
		Channel
                .fromPath(params.manifest)
		.splitText()
                .set { accs }
		sra_pull(accs)
	}

}
